@@ -77,7 +77,7 @@ class Logger:
 
         return datetime.now(timezone.utc).strftime(self.iso_8601_format)
 
-    def _get_timestamp(self) -> None:
+    def _get_timestamp(self) -> str:
         """
         Returns the current timestamp in a formatted string.
 
@@ -88,7 +88,7 @@ class Logger:
             return datetime.now(timezone.utc).strftime(self.time_format)
         return self._get_iso_8601_timestamp()
 
-    def _format_message(self, message: str, loglevel: LogLevel) -> dict:
+    def _format_message(self, message: str, loglevel: LogLevel) -> dict[str]:
         """
         Formats the log message with additional information.
 
@@ -221,3 +221,15 @@ class Logger:
             ValueError: If the level is not supported.
         """
         self._log(message, loglevel=LogLevel.CRITICAL)
+
+    def catch_debug(self, func):
+        def wrapper(*args, **kwargs):
+            try:
+                self.debug(f"func '{func.__name__}' with {args}, {kwargs}")
+                result = func(*args, **kwargs)
+                self.debug(f"func '{func.__name__}' completed successfully, \
+with '{result}'")
+                return result
+            except Exception as e:
+                self.error(f"{func.__name__} failed with error: {str(e)}")
+        return wrapper
